C     -----------------------------------------------------------------
      SUBROUTINE SUBR01(M,R,ZC92,A0BVT,FAULT)
C     =======================================
C
C     Purpose
C     -------
C     Subroutine 1 calculates [aplha 0BV / alpha 0BT]
C
C     Input
C     -----
C     M     - Mach number
C     R     - Reynolds number
C     ZC92  - [zc92 / zc50]
C
C     Output
C     ------
C     A0BVT - [alpha 0BV / alpha 0BT]
C     FAULT - fault number
C
C     Local
C     -----
C     KV    - factor read from Figure 1 of Item 98011
C     KM0   - number read from Figure 2 of Item 98011
C     KM    - factor given by formula
C     LGR   - log10(R)
C     LGZ   - log10(zc92 / zc50)
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL M,R,ZC92,A0BVT
C
      REAL KV,KM0,KM,LGR,LGZ
C
      FAULT = 0
C
C     Calculate and check log10(R) and log10(zc92 / zc50)
C     ---------------------------------------------------
      IF (R .LE. 0.0) FAULT = 2001
      IF (ZC92 .LE. 0.0 .OR. ZC92 .GT. 10.0) FAULT = 2002
      IF (FAULT .NE. 0) GO TO 10
      LGR = LOG10(R)
      LGZ = LOG10(ZC92)
C
C     Figure 1 of Item 98011 gives KV
C     -------------------------------
      CALL FIG37A(LGZ,LGR,KV,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Calculate KM
C     ------------
C     If log10(zc92 / zc50) < -1.0 then KM = 1.0
C     Otherwise read KM0 from Figure 2 of Item 98011 and calculate KM
      KM = 1.0
      IF (LGZ .GE. -1.0) THEN
       CALL FIG38A(LGR,M,KM0,FAULT)
       IF (FAULT .NE. 0) GO TO 10
       KM = KM0 + (KM0 - 1.0) * LGZ
      END IF
C
C     [alpha 0BV / alpha 0BT] is given by
C     -----------------------------------
      A0BVT = KV * KM
C
   10 CONTINUE
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBR02(MK,RK,XTR,TAUA,TAUAU,RA,FAULT)
C     ================================================
C
C     Purpose
C     -------
C     Subroutine 2 calculates [(a1)0V / (a1)0T]
C
C     Input
C     -----
C     MK,RK   - Mach and Reynolds numbers
C     XTR     - [xtr / c]
C     TAUA    - [tau a]
C     TAUAU   - [tau au]
C
C     Output
C     ------
C     RA      - [(a1)0V / (a1)0T]
C     FAULT   - fault number
C
C     Local
C     -----
C     BETA    - beta = sqrt(1-MK**2)
C     RASYM   - [(a1)0V / (a1)0T]sym
C     DRA     - Delta[(a1)0V / (a1)0T]
C     LGR     - log10(RK)
C     TN      - tan(tau a / (2*beta))
C     DTN     - tan(tau au) - tan(tau a / 2)
C     DTOR    - (radians) = DTOR * (degrees)
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL MK,RK,XTR,TAUA,TAUAU,RA
C
      REAL BETA,RASYM,DRA,LGR,TN,DTN,DTOR
C
      DTOR = 3.141593 / 180.0
      FAULT = 0
C
C     Check MK and RK
C     ---------------
      IF (MK .LE. 0.0 .OR. MK .GE. 0.9) FAULT = 2003
      IF (RK .LE. 0.0) FAULT = 2004
      IF (FAULT .NE. 0) GO TO 10
C
C     Calculate beta, log10(RK) and tan(tau a / (2*beta))
C     and tan(tau au) - tan(tau a / 2)
C     ---------------------------------------------------
      BETA = SQRT(1.0 - MK * MK)
      LGR = LOG10(RK)
      TN = TAN(DTOR * TAUA / (2.0 * BETA))
      DTN = TAN(DTOR * TAUAU) - TAN(DTOR * TAUA / 2.0)
C
C     Figures 1 to 6 of Item 97020 give [(a1)0V / (a1)0T]sym
C     as a function of (xtr/c), tan[(tau a)/(2*beta)] and log10(Rk)
C     -------------------------------------------------------------
      CALL FIG39A(XTR,TN,LGR,RASYM,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     Figures 7 to 9 of Item 97020 give Delta[(a1)0V / (a1)0T]
C     as a function of log10(Rk), {tan(tau au)-tan[(tau a)/s]}
C     and Mk
C     --------------------------------------------------------
      CALL FIG40A(LGR,DTN,MK,DRA,FAULT)
      IF (FAULT .NE. 0) GO TO 10
C
C     The result is given by
C     [(a1)0V / (a1)0T] = [(a1)0V / (a1)0T]sym + Delta[(a1)0V / (a1)0T]
C     -----------------------------------------------------------------
      RA = RASYM + DRA
C
   10 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBR03(CXC0,CELCX0,K0,DCL0L2,DL,DCL0LG,FAULT)
C     ========================================================
C
C     Purpose
C     -------
C     Subroutine 3 calculates [Delta CL0l]gen
C
C     Input
C     -----
C     CXC0      - (c'/c)0
C     CELCX0    - (cel/c')0
C     K0        - K0
C     DCL0L2    - [Delta C'L0l]2
C     DL        - delta l (in degrees)
C
C     Output
C     ------
C     DCL0LG    - [Delta CL0l]gen
C     FAULT     - fault number
C
C     Local
C     -----
C     DTOR      - (radians) = DROT * (degrees)
C     X         - 1 - 2 * (cel/c')0
C     CS        - arc cos(1 - 2 * (cel/c')0)
C     TOL       - tolerance
C     AL        - factor (al) in the notes
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL CXC0,CELCX0,K0,DCL0L2,DL,DCL0LG
C
      REAL DTOR,X,CS,TOL,AL
C
      TOL = 1.0E-8
      TOL = TOL
      DTOR = 3.141593 / 180.0
      FAULT = 0
C
C     Calculate and check X and CS
C     ----------------------------
C     X = 1.0 - 2.0 * (cel/c')0
      X = 1.0 - 2.0 * CELCX0
C
      IF (ABS(X) .GT. 1.0) FAULT = 2005
      IF (FAULT .NE. 0) GO TO 10
      CS = ACOS(X)
C
C     (al) = - 2.0 * {arc cos[1.0 - 2.0 * (cel/c')0]
C                   - sqrt[1 - [1.0 - 2.0 * (cel/c')0]^2}
C     ---------------------------------------------------
      AL = - 2.0 * (CS - SQRT(1.0 - X * X))
C
C
C     [Delta CL0l]gen =
C     (c'/c)0 * [(pi/180) * K0 * al * (delta l) + (Delta C'L0l)2]
C     -----------------------------------------------------------
      DCL0LG = CXC0 * (DTOR * K0 * AL * DL + DCL0L2)
C
   10 RETURN
      END
C     -----------------------------------------------------------------
C
      SUBROUTINE SUBR04(CELCXM,KE,KG,KL,D0,DL,RSLT,FAULT)
C     ===================================================
C
C
C     Purpose
C     -------
C     Subroutine 4 calculates [Delta CLml / FR Phi i]gen
C
C     Input
C     -----
C     CELCXM    - (cel/c')m
C     KE,KG,KL  - Ke, Kg, Kl
C     D0,DL     - delta 0, delta l
C
C     Output
C     ------
C     RSLT      - [Delta CLml / FR Phi i]gen
C     FAULT     - fault number
C
C     Local
C     -----
C     X         - 1.0 - 2.0 * (cel/c')m
C     CS        - arc cos(1 - 2 (cel/c')m)
C     TOL       - tolerance
C     AML       - aml
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL CELCXM,KE,KG,KL,D0,DL,RSLT
C
      REAL CS,TOL,AML,X
C
      TOL = 1.0E-8
      TOL = TOL
      FAULT = 0
C
C     Calculate and check X and cos(X)
C     --------------------------------
C     X = 1.0 - 2.0 * (cel/c')m
      X = 1.0 - 2.0 * CELCXM
C
      IF (ABS(X) .GT. 1.0) FAULT = 2006
      IF (FAULT .NE. 0) GO TO 10
      CS = ACOS(X)
C
C     aml = 2 sin[arc cos(1 - 2 (cel/c')m)]
C     -------------------------------------
      AML = 2.0 * SIN(CS)
C
C     [Delta CLml / FR Phi i]gen =
C     Ke * Kg * Kl * aml *[(delta l) - (delta 0)]
C     -------------------------------------------
C
      RSLT = KE * KG * KL *AML * (DL * 3.141593 / 180.0 - D0)
C
C
   10 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBR05(R,T,TAU,TAUA,A1OLD,FAULT,XTR2)
C     ===========================================
C
C     Purpose
C     -------
C     Subroutine 5 calculates (a1)old
C
C     Input
C     -----
C     R         - Reynolds number
C     T         - t/c
C     TAU,TAUA  - tau and tau a
C
C     Output
C     ------
C     A1OLD     - (a1)old
C     FAULT     - fault number
C
C     Local
C     -----
C     DTOR      - (radians) = DTOR * (degrees)
C     PI        - 3.141593
C     TN        - tan(tau a / 2)
C     LGRM5     - log10(R) - 5.0
C     TOP,BOT   - dividend and divisor
C     TOL       - tolerance
C     RA1       - [(a1)0V / (a1)0T]old
C     A1        - (a1)0Told
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL R,T,TAU,TAUA,A1OLD,XTR2
C
      REAL DTOR,PI,TN,LGRM5,TOP,BOT,TOL,RA1,A1
C
      PI = 3.141593
      DTOR = PI / 180.0
      TOL = 1.0E-8
C
      FAULT = 0
C
C     Calculate and check log10(R) - 5
C     --------------------------------
      IF (R .LE. 1.0E5) FAULT = 2007
      IF (FAULT .NE. 0) GO TO 10
      LGRM5 = LOG10(R) - 5.0
      IF (LGRM5 .LE. TOL) FAULT = 2007
      IF(FAULT .NE. 0) GO TO 10
C
C     Calculate tan(taua / 2)
C     -----------------------
      TN = TAN(0.5 * DTOR * TAUA)
C
C     Calculate TOP = 0.1 + 1.05 tan(taua / 2) and
C     BOT = (log10(R) - 5)**(1 - 2.5 tan(taua / 2))
C     and check TOP/BOT
C    ----------------------------------------------
C
      TOP = 0.1 + (1.05 - 0.5 * XTR2) * TN
      BOT = LGRM5**(1.0 - 2.5 * TN)
      IF (ABS(BOT) .LE. TOL * ABS(TOP)) FAULT = 2008
      IF (FAULT .NE. 0) GO TO 10
C
C     [(a1)0V / (a1)0T]old =
C     1.0 - [0.1 + 1.05 tan(taua / 2)]
C                / [log10(R) - 5)**(1 - 2.5 tan(taua / 2)]
C     ----------------------------------------------------
      RA1 = 1.0 - TOP / BOT
C
C     (a1)0Told = 2 * pi + (4.75 + 0.02 * tau) * (t/c)
C     ------------------------------------------------
      A1 = 2.0 * PI + (4.75 + 0.02 * TAU) * T
C
C     (a1)old = (a1)0Told * [(a1)0V / (a1)0T]old
C     ------------------------------------------
      A1OLD = A1 * RA1
   10 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBR06(ZUG2,ZLG2,A0BT2)
C     ==================================
C
C     Purpose
C     -------
C     Subroutine 6 calculates alpha 0BT2
C
C     Input
C     -----
C     ZUG2(17)    - (zu/c)g2 with g2 = 1 to 17
C     ZLG2(17)    - (zl/c)g2 with g2 = 1 to 17
C
C     Output
C     ------
C     A0BT2       - alpha 0BT2
C
C     Local
C     -----
C     G2          - index g2
C     B(17)       - array of stored coefficients
C
C     -----------------------------------------------------------------
C
      REAL ZUG2(17),ZLG2(17),A0BT2
C
      INTEGER G2
      REAL B(17)
C
      DATA B /
     *  1.45,   0.0,   0.0, 2.11,    1.56,  2.41,
     *  2.94,  2.88,  3.13, 3.67,    4.69,  6.72,
     * 11.75, 21.72, 99.85,  0.0, -164.88/
C
C     (alpha 0BT2) =
C     - (pi/180) * Sigma[(Bg)2 * [(zu/c)g2 + (zl/c)g2] / 2]
C     for g2 = 1 to 17
C     -----------------------------------------------------
      A0BT2 = 0.0
      DO 10 G2 = 1,17
      A0BT2 = A0BT2 - B(G2) * (ZUG2(G2) + ZLG2(G2))
   10 CONTINUE
      A0BT2 = (3.141593 / 180.0) * A0BT2
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBR07(R,ZU125,LDA,TNTU,LDA2,DCL,FAULT)
C     ==================================================
C
C     Purpose
C     -------
C     Subroutine 7 calculates Delta CL
C
C     Input
C     -----
C     R        - Reynolds number
C     ZU125    - (zu/c)1.25
C     LDA      - Lambda (deg)
C     TNTU     - tan(tau u)
C     LDA2     - Lambda2  (deg)
C
C     Output
C     ------
C     DCL      - Delta CL
C     FAULT    - fault number
C
C     Local
C     -----
C     DTOR     - (radians) = DTOR * (degrees)
C     CS       - cos(of an angle)
C     RCSQ     - R * cos^2(Lambda)
C     ZUSEC    - (zu/c)1.25 * sec(Lambda)
C     TNSEC2   - tan(tau u) * sec(Lambda2)
C     TOL      - tolerance
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL R,ZU125,LDA,TNTU,LDA2,DCL
C
      REAL CS,RCSQ,ZUSEC,TNSEC2,DTOR,TOL
C
      DTOR = 3.141593 / 180.0
      TOL = 1.0E-8
      FAULT = 0
C
C     Calculate R * cos^2(Lambda), (zu/c)1.25 * sec(Lambda)
C     and tan(tau u) * sec(Lambda2)
C     -----------------------------------------------------
      CS = COS(DTOR * LDA)
C     RCSQ = R * cos^2(Lambda)
      RCSQ = R * CS * CS
C
      IF (ABS(CS) .LE. TOL * ABS(ZU125)) FAULT = 2009
      IF (FAULT .NE. 0) GO TO 10
C     ZUSEC = (zu/c)1.25 * sec(Lambda)
      ZUSEC = ZU125 / CS
C
      CS = COS(DTOR * LDA2)
      IF (ABS(CS) .LE. TOL * TNTU) FAULT = 2010
      IF (FAULT .NE. 0) GO TO 10
C     TNSEC2 = tan(tau u) * sec(Lambda2)
      TNSEC2 = TNTU / CS
C
      IF (ZUSEC .LT. 0.017) THEN
C      If (zu/c)1.25 * sec(Lambda) < 0.017
C      then Figure 1 of Item 84026 gives (Delta CL)
C      as a function of [(zu/c)1.25 * sec(Lambda)]
C      and [R * cos^2(Lambda)]
C      --------------------------------------------
       CALL FIG04A(ZUSEC,RCSQ,DCL,FAULT)
      ELSE
C      Otherwise Figure 2 of Item 84026 gives (Delta CL)
C      as a function of [R * cos^2(Lambda)] and
C      [tan(tau u) * sec(Lambda2)]
C      -------------------------------------------------
       CALL FIG05A(RCSQ,TNSEC2,DCL,FAULT)
      END IF
C
   10 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBR08(R,LDA,ITYPE,ZU09,ZL09,ZU10,ZL10,FS,MSG,FAULT)
C     ===============================================================
C
C     Purpose
C     -------
C     Subroutine 8 calculates Fs
C
C     Input
C     -----
C     R         - Reynolds number
C     LDA       - Lambda
C     ITYPE     - integer version of TYPE
C                 1 = 'P' = program decides
C                 2 = 'M' = modern
C                 3 = 'C' = conventional
C     ZU09,ZL09 - (zu/c)0.9 and (zl/c)0.9
C     ZU10,ZL10 - (zu/c)1.0 and (zl/c)1.0
C
C     Output
C     ------
C     FS        - Fs
C     MSG       - message number for output
C     FAULT     - fault number
C
C     Local
C     -----
C     TST1      - [(zu/c)0.9 - (zl/c)0.9] / (zu/c)0.9
C     TST2      - [(zu/c)1.0 - (zl/c)1.0]
C     CHECK     - integer flag (0 or 1)
C     DTOR      - (radians) = DTOR * (degrees)
C     CS        - cos(Lambda)
C     RCSQ      - R * cos^2(Lambda)
C
C     -----------------------------------------------------------------
C
      INTEGER ITYPE,MSG,FAULT
      REAL R,LDA,ZU09,ZL09,ZU10,ZL10,FS
C
      INTEGER CHECK
      REAL TST1,TST2,DTOR,CS,RCSQ
C
      DTOR = 3.141593 / 180.0
      MSG = 0
      FAULT = 0
C
C     Calculate R * cos^2(Lambda)
C     ---------------------------
      CS = COS(DTOR * LDA)
      RCSQ = R * CS * CS
C
C     Set the flag CHECK to 0 or 1
C     ----------------------------
C     TST1 =  [(zu/c)0.9 - (zl/c)0.9] / (zu/c)0.9
      TST1 = (ZU09 - ZL09) / ZU09
C
C     TST2 =  [(zu/c)1.0 - (zl/c)1.0]
      TST2 = ZU10 - ZL10
C
      IF (TST1 .GT. 0.64 .AND. TST2 .GT. 0.004) THEN
       CHECK = 1
      ELSE
       CHECK = 0
      END IF
C
C     The next action depends on the parameter TYPE
C     =============================================
      GO TO (10, 20, 30), ITYPE
C
C     TYPE = 'P'
C     ---------
   10 IF (CHECK .EQ. 1) THEN
C      Figure 5 of Item 84026 gives Fs
C      as a function of R * cos^2(Lambda)
       CALL FIG06A(RCSQ,FS,FAULT)
       MSG = 1
      ELSE
       FS = 1.0
       MSG = 2
      END IF
      GO TO 40
C
C     TYPE = 'M'
C     ----------
C     Figure 5 of Item 84026 gives Fs
C     as a function of R * cos^2(Lambda)
   20 CALL FIG06A(RCSQ,FS,FAULT)
      IF (CHECK .EQ. 1) THEN
       MSG = 3
      ELSE
       MSG = 4
      END IF
      GO TO 40
C
C     TYPE = 'C'
C     ----------
   30 FS = 1.0
      IF(CHECK .EQ. 0) THEN
       MSG = 5
      ELSE
       MSG = 6
      END IF
      GO TO 40
C
   40 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBR09(ZUG,ZLG,A0BT)
C     ===============================
C
C     Purpose
C     -------
C     Subroutine 9 calculates alpha 0BT
C
C     Input
C     -----
C     ZUG(15),ZLG(15) - (zu/c)g and (zl/c)g
C                       These are either:
C                       (1) (zu/c)rg and (zl/c)rg or
C                       (2) (zu/c)2/3g and (zl/c)2/3g
C
C     Output
C     ------
C     A0BT     - alpha 0BT
C
C     Local
C     -----
C     G        - index g (g = 1 to 15)
C     BX(15)   - fifteen coefficients (B')g with g = 1 to 15
C
C     -----------------------------------------------------------------
C
      REAL ZUG(15),ZLG(15),A0BT
C
      INTEGER G
      REAL BX(15)
C
      DATA BX /
     *  1.45,  2.11,  1.56, 2.41,    2.94,
     *  2.88,  3.13,  3.67, 4.69,    6.72,
     * 11.75, 21.72, 99.85,  0.0, -164.88/
C
C     (alpha 0BT) =
C     - (pi/180) * Sigma[(B')g * [(zu/c)g + (zl/c)g] / 2]
C     for g = 1 to 15
C     ---------------------------------------------------
      A0BT = 0.0
      DO 10 G = 1,15
      A0BT = A0BT - BX(G) * (ZUG(G) + ZLG(G))
   10 CONTINUE
      A0BT = (3.141593 / 180.0) * A0BT
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBR11(CT,CXC,A0T,FAULT)
C     ===================================
C
C     Purpose
C     -------
C     Subroutine 11 calculates a0t
C
C     Input
C     -----
C     CT     - (ct/c)
C     CXC    - (c'/c)
C
C     Output
C     ------
C     A0T    - a0t (1/radians)
C     FAULT  - fault number
C
C     Local
C     -----
C     X     - 2 (ct/c) / (c'/c) - 1
C     CS    - arc cos(X)
C     TOL   - tolerance
C
C     -----------------------------------------------------------------
C
      INTEGER FAULT
      REAL CT,CXC,A0T
C
      REAL X,CS,TOL
C
      TOL = 1.0E-8
      FAULT = 0
C
      IF (ABS(CXC) .LE. TOL * CT) FAULT = 2011
      IF (FAULT .NE. 0) GO TO 10
C
C     X = [2 * (ct/c) / (c'/c) - 1]
      X = 2.0 * CT / CXC - 1.0
C
C
      IF (ABS(X) .GT. 1.0) FAULT = 2012
      IF (FAULT .NE. 0) GO TO 10
C
C     CS = arc cos[2 * (ct/c) / (c'/c) - 1]
      CS = ACOS(X)
C
C     (a0t) = 2 * {pi - arc cos[2 * (ct/c) / (c'/c) - 1]
C                  + sqrt[1 - cos[2 * (ct/c) / (c'/c) - 1]^2]}
C     --------------------------------------------------------
      A0T = 2.0 * (3.141593 - CS + SQRT(1.0 - X * X))
C
C
   10 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBR12(EIL,W,DEIL)
C     =============================
C
C     Purpose
C     -------
C     Subroutine 12 calculates Delta eta il
C
C     Input
c     -----
C     EIL     - eta il
C     W       - W/s
C
C     Output
C     ------
C     DEIL    - Delta eta il
C
C     -----------------------------------------------------------------
C
      REAL EIL,W,DEIL
C
      IF ((EIL - 0.5 * W) .LE. 0.005) THEN
C      If [(eta il) - (1/2) * (W/s)] <= 0.005
C      then (Delta eta il) = (eta il) *(W/s)
C      --------------------------------------
      DEIL = EIL
C
      ELSE
C      (Delta eta il) = 0.0
C      --------------------
       DEIL = 0.0
      END IF
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBR13(EIT,W,H,DEIT)
C     ===============================
C
C     Purpose
C     -------
C     Subroutine 13 calculates Delta eta it
C
C     Input
C     -----
C     EIT    - (eta it)
C     W      - (W/s)
C     H      - (h/H)
C
C     Output
C     ------
C     DEIT   - (Delta eta it)
C
C     Local
C     -----
C     TST    - (eta it) - 0.5 (W/s)
C
C     -----------------------------------------------------------------
C
      REAL EIT,W,H,DEIT
C
      REAL TST
C
      TST = EIT - 0.5 * W
C
      IF (TST .LE. 0.005) THEN
C
C      If [(eta it) - (1/2) * (W/s)] <= 0.005
C      then (Delta eta it) = (W/s) * [0.25 + 0.3 * (h/H)]
C      ----------------------------------------------------------
       DEIT = W * (0.25 + 0.3 * H)
C
      ELSE
C      Otherwise it exceeds 0.005 and then
C
       IF (TST .LE. 0.05) THEN
C
C       If 0.005 <= [(eta it) - (1/2) * (W/s)] <= 0.05
C       (Delta eta it) =
C       {[0.05 - [(eta it) - (1/2) * (W/s)]] / 0.045}
C       *[0.25 + 0.3 * (h/H)] *  (W/s)
C       ----------------------------------------------
C
        DEIT = ((0.05 - TST) / 0.045) * W * (0.25 + 0.3 * H)
C
       ELSE
C
C       Otherwise 0.05 < [(eta it) - (1/2) * (W/s)]
C       and (Delta eta it) = 0.0
C       -------------------------------------------
        DEIT = 0.0
       END IF
      END IF
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBR14(R,CL0TOT,CLMTOT,LCS,D,P,A0,AX,ACLMX,
     *                  NCL,CL,AD,FAULT)
C     ======================================================
C
C     Purpose
C     -------
C     Subroutine 14 calculates arrays of alpha and CL for printout
C     and also (alpha 0), (alpha *) and (alpha CLmax)
C
C     Input
C     -----
C     R      - Reynolds number based on cp in paragraph 3 [R'k]
C     CL0TOT - Cl0 or CL0W or CL0WF   (according to CALC)
C     CLMTOT - CLM or CLMXW or CLMXWF (according to CALC)
C     LCS    - lift-curve slope [a] in paragraph b1
C     D      - factor D in paragraph k2
C     P      - power p in paragraph k3
C
C     Output
C     ------
C     A0      - angle of attack for zero lift [alpha 0]
C               (in radians until final conversion to degrees)
C     AX      - alpha* in the notes
C               (in radians until final conversion to degrees)
C     ACLMX   - angle of attack for maximum lift (deg) [alpha CLmax]
C     NCL     - number of coordinates in the arrays CL(),AD() NCL <= 200
C     CL(200) - NCL lift coefficients CL
C     AD(200) - NCL angles of attack (deg) [alpha d]
C     FAULT   - fault number
C
C     Local
C     -----
C     DTOR        - (radians) = DTOR * (degrees)
C     RTOD        - (degrees) = RTOD * (radians)
C     N (real)    - power N read from Figure 1 of Item 96003
C     CS          - cosine of an angle
C     CSN         - [cos(angle)]**N
C     TN          - tan of an angle
C     A01,A02,A03 - (alpha0)1, (alpha0)2, (alpha0)3 (rad)
C     AX1,AX2,AX3 - (alpha*)1, (alpha*)2, (alpha*)3 (rad)
C     LCSX        - a* in the notes (1/rad)
C     A           - angle of attack (rad) [alpha]
C     I           - starting integer for plot coordinates
C     J           - number of coordinate pairs
C     X           - a real number <= I
C     TOL         - tolerance
C     TOP,BOT     - dividend and divisor
C
C     -----------------------------------------------------------------
C
      INTEGER NCL,FAULT
      REAL R,CL0TOT,CLMTOT,LCS,D,P,A0,AX,ACLMX,CL(200),AD(200)
C
      INTEGER I,J
      REAL TOL,TOP,BOT
      REAL DTOR,RTOD,N,CS,CSN,TN,A01,A02,A03,AX1,AX2,AX3,LCSX,A,X
C
      FAULT = 0
      NCL = 0
      DTOR = 3.141593 / 180.0
      RTOD = 180.0 / 3.141593
      TOL = 1.0E-8
C
C     Figure 1 of Item 96003 gives N as a function of LOG10(R)
C     --------------------------------------------------------
C
      CALL FIG36A(ALOG10(R),N,FAULT)
      IF (FAULT .NE. 0) GO TO 50
C
C     Calculate (alpha0)1 = - CL0TOT / (a * D)
C     ----------------------------------------
      IF (ABS(LCS * D) .LE. TOL * ABS(CL0TOT)) FAULT = 2014
      IF (FAULT .NE. 0) GO TO 50
      A01 = - CL0TOT / (LCS * D)
C
C     Calculate (alpha0)2 = (alpha0)1 / cos^N[(-alpha0)1]
C     ---------------------------------------------------
      CS = COS(A01)
C
      CS = ABS(CS)
C
      IF (CS .LE. TOL) FAULT = 2015
      IF (FAULT .NE. 0) GO TO 50
      CSN = CS**N
      IF (CSN .LE. TOL * ABS(A01)) FAULT = 2016
      IF (FAULT .NE. 0) GO TO 50
      A02 = A01 / CSN
C
C     Calculate (alpha0)3 = (alpha0)1 / cos^N[(-alpha0)2]
C     ---------------------------------------------------
      CS = COS(A02)
C
      CS = ABS(CS)
C
      IF (CS .LE. TOL) FAULT = 2017
      IF (FAULT .NE. 0) GO TO 50
      CSN = CS**N
      IF (CSN .LE. TOL * ABS(A01)) FAULT = 2018
      IF (FAULT .NE. 0) GO TO 50
      A03 = A01 / CSN
C
C     Calculate alpha0 = (alpha0)1 / cos^N[(-alpha0)3]
C     ------------------------------------------------
      CS = COS(A03)
C
      CS = ABS(CS)
C
      IF (CS .LE. TOL) FAULT = 2019
      IF (FAULT .NE. 0) GO TO 50
      CSN = CS**N
      IF (CSN .LE. TOL * ABS(A01)) FAULT = 2020
      IF (FAULT .NE. 0) GO TO 50
      A0 = A01 / CSN
C TWO MORE ITERATIONS THAN ITEM TO BE SAFE
      CS = COS(A0)
C
      CS = ABS(CS)
C
      IF (CS .LE. TOL) FAULT = 2019
      IF (FAULT .NE. 0) GO TO 50
      CSN = CS**N
      IF (CSN .LE. TOL * ABS(A01)) FAULT = 2020
      IF (FAULT .NE. 0) GO TO 50
      A0 = A01 / CSN
C
      CS = COS(A0)
C
      CS = ABS(CS)
C
      IF (CS .LE. TOL) FAULT = 2019
      IF (FAULT .NE. 0) GO TO 50
      CSN = CS**N
      IF (CSN .LE. TOL * ABS(A01)) FAULT = 2020
      IF (FAULT .NE. 0) GO TO 50
      A0 = A01 / CSN
C
C
C     Calculate (alpha*)1 = (CLMTOT - 0.3) / (a * D) + alpha0
C     -------------------------------------------------------
      IF (ABS(LCS * D) .LE. TOL * (CLMTOT - 0.3)) FAULT = 2021
      IF (FAULT .NE. 0) GO TO 50
      AX1 = (CLMTOT - 0.3) / (LCS * D) + A0
C
C     Calculate (alpha*)2
C     = [(alpha*)1 - alpha0] / cos^N[(alpha*)1 - alpha0] + alpha0
C     -----------------------------------------------------------
      TOP = AX1 - A0
      CS = COS(TOP)
C
      CS = ABS(CS)
C
      IF (CS .LE. TOL) FAULT = 2022
      IF (FAULT .NE. 0) GO TO 50
      CSN = CS**N
      IF (CSN .LE. TOL * ABS(TOP)) FAULT = 2023
      IF (FAULT .NE. 0) GO TO 50
      AX2 = TOP / CSN + A0
C
C     Calculate (alpha*)3
C     = [(alpha*)1 - alpha0] / cos^N[(alpha*)2 - alpha0] + alpha0
C     -----------------------------------------------------------
      CS = COS(AX2 - A0)
C
      CS = ABS(CS)
C
      IF (CS .LE. TOL) FAULT = 2024
      IF (FAULT .NE. 0) GO TO 50
      CSN = CS**N
      IF (CSN .LE. TOL * ABS(TOP)) FAULT = 2025
      IF (FAULT .NE. 0) GO TO 50
      AX3 = TOP / CSN + A0
C
C     Calculate alpha*
C     = [(alpha*)1 - alpha0] / cos^N[(alpha*)3 - alpha0] + alpha0
C     -----------------------------------------------------------
      CS = COS(AX3 - A0)
C
      CS = ABS(CS)
C
      IF (CS .LE. TOL) FAULT = 2026
      IF (FAULT .NE. 0) GO TO 50
      CSN = CS**N
      IF (CSN .LE. TOL * ABS(TOP)) FAULT = 2027
      IF (FAULT .NE. 0) GO TO 50
      AX = TOP / CSN + A0
C TWO MORE ITERATIONS THAN ITEM TO BE SAFE
      CS = COS(AX - A0)
C
      CS = ABS(CS)
C
      IF (CS .LE. TOL) FAULT = 2026
      IF (FAULT .NE. 0) GO TO 50
      CSN = CS**N
      IF (CSN .LE. TOL * ABS(TOP)) FAULT = 2027
      IF (FAULT .NE. 0) GO TO 50
      AX = TOP / CSN + A0
C
      CS = COS(AX - A0)
C
      CS = ABS(CS)
C
      IF (CS .LE. TOL) FAULT = 2026
      IF (FAULT .NE. 0) GO TO 50
      CSN = CS**N
      IF (CSN .LE. TOL * ABS(TOP)) FAULT = 2027
      IF (FAULT .NE. 0) GO TO 50
      AX = TOP / CSN + A0
C
C
C     Calculate LCSX = a* = a * D * cos^N(alpha* - alpha0)
C                    * [1 - N *(alpha* - alpha0) * tan(alpha* - alpha0)]
C     ------------------------------------------------------------------
      CS = COS(AX - A0)
C
      CS = ABS(CS)
C
      IF (CS .LE. 0.0) FAULT = 2028
      IF (FAULT .NE. 0) GO TO 50
      CSN = CS**N
      TN = TAN(AX - A0)
      LCSX = LCS * D * CSN * (1.0 - N * (AX - A0) * TN)
C
C     Find I for the first (alpha d) which is AD(1) = I / 4 (degrees)
C     where I is the first integer >= 4 * (180/pi) * (alpha0)
C     ---------------------------------------------------------------
      X = 4.0 * RTOD * A0
      I = X
      IF ((I - X) .LT. 0.0) I = I + 1
C
C     Calculate CL for (alpha d) = I/4, I/4+0.25, I/4+0.5 etc until
C     (alpha* - alpha)*180/pi < 0.25
C     =============================================================
      DO 10 J = 1,200
      AD(J) = 0.25 * (I + J - 1)
      A = DTOR * AD(J)
      IF (RTOD * (AX - A) .LT. 0.25) GO TO 20
C
      NCL = NCL + 1
      CS = COS(A - A0)
C
      CS = ABS(CS)
C
      IF (CS .LT. 0.0) FAULT = 2029
      IF (FAULT .NE. 0) GO TO 50
C
C     CL = a * D * (alpha - alpha0) * cos^N(alpha - alpha0)
C     -----------------------------------------------------
      CL(J) = LCS * D * (A - A0) * CS**N
C
   10 CONTINUE
C
   20 IF (NCL .EQ. 200) FAULT = 2030
      IF (FAULT .NE. 0) GO TO 50
C
C     Then calculate
C     CL = CLMTOT - 0.3 *[1 - (a*) * (alpha - alpha*) / (0.3 * p)]^p
C     until
C     [alpha - (alpha* + 0.3 * p / (a*)] * 180 / pi < 0.25
C     ==============================================================
      DO 30 J = NCL + 1, 200
      AD(J) = 0.25 * (I + J - 1)
      A = DTOR * AD(J)
C
      IF (ABS(LCSX) .LE. TOL * ABS(0.3 * P)) FAULT = 2031
      IF (FAULT .NE. 0) GO TO 50
C
C     Check for the limit of
C     [- alpha + (alpha* + 0.3 * p / (a*)] * 180 / pi < 0
C     ----------------------------------------------------
C
      X = (- A + (AX + 0.3 * P / LCSX)) * RTOD
C
      IF (X .LT. 0.0) GO TO 40
C
      NCL = NCL + 1
C
C     TOP = (a*) * (alpha - alpha*)
      TOP = LCSX * (A - AX)
      BOT = 0.3 * P
C
      IF (ABS(BOT) .LE. TOL * ABS(TOP)) FAULT = 2032
      IF (FAULT .NE. 0) GO TO 50
C
C     X = 1 - (a*) * (alpha - alpha*) / (0.3 * p)
      X = 1.0 - TOP / BOT
      IF (X .LT. 0.0) FAULT = 2032
      IF (FAULT .NE. 0) GO TO 50
C
C     CL = CLMTOT - 0.3 *[1 - (a*) * (alpha - alpha*) / (0.3 * p)]^p
C     --------------------------------------------------------------
      CL(J) = CLMTOT - 0.3 * X**P
C
   30 CONTINUE
C
C     Calculate alpha CLmax
C     = (alpha* + 0.3 * p / (a*)) * 180 / pi
C     --------------------------------------
   40 ACLMX = (AX + 0.3 * P  / LCSX) * RTOD
C
C     Convert alpha0 and alpha* to degrees
C     ------------------------------------
      A0 = RTOD * A0
      AX = RTOD * AX
C
   50 RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBR15(EIL,EOT,W,P)
C     ==============================
C
C     Purpose
C     -------
C     Subroutine 15 calculates p
C
C     Input
C     -----
C     EIL,EOT   - (eta il) and (eta ot)
C     W         - (W / s)
C
C     Output
C     ------
C     P         - p
C
C     -----------------------------------------------------------------
C
      REAL EIL,EOT,W,P
C
      IF (EIL .GE. 0.25 * (1.0 - 0.5 * W)) THEN
C
C      If (eta il) >= 0.25 * [1 - (W/s)] then
C      p = 1.45 + 0.35 * |0.5 - (eta ot)| / 0.5
C      ----------------------------------------
       P = 1.45 + 0.35 * ABS(0.5 - EOT) / 0.5
C
      ELSE
C
C      Otherwise
C      p = [1.45 + 0.35 * |0.5 - (eta ot)| / 0.5 - 1.3] * (eta il)/0.25
C          + 1.3
C      ----------------------------------------------------------------
       P = (1.45 + 0.35 * ABS(0.5 - EOT) / 0.5 - 1.3) * EIL / 0.25 + 1.3
C
      END IF
C
      RETURN
      END
C     -----------------------------------------------------------------
      SUBROUTINE SUBERR(OUTFIL,FAULT)
C     ===============================
C
C     Purpose
C     -------
C     To print an error found by Subroutines 1 to 15 (SUBR01 to SUBR15)
C
C     Input
C     -----
C     OUTFIL    - output unit number
C     FAULT     - fault number
C                 (This set of fault numbers runs from 2001 to 2032.)
C
C     Local
C     -----
C     TXT(2,31) - two lines of text per message
C     I,J       - array indices
C
C     -----------------------------------------------------------------
C
      INTEGER OUTFIL,FAULT
C
      INTEGER I,J
      CHARACTER*62 TXT
      COMMON /SUBTXT/ TXT(2,32)
C
      J = FAULT - 2000
      IF (J .GT. 0 .AND. J .LE. 32) THEN
       WRITE(OUTFIL,10) (TXT(I,J), I = 1,2)
   10  FORMAT(2(/,1X,A62),/)
      ELSE
       WRITE(OUTFIL,20) FAULT
   20  FORMAT(1X,'Program error - Error ',I5,' should not exist.')
      END IF
C
      RETURN
      END
C     -----------------------------------------------------------------
      BLOCK DATA SUBFLT
C     =================
C
      INTEGER I,J
      CHARACTER*62 TXT
      COMMON /SUBTXT/ TXT(2,32)
C
      DATA ((TXT(I,J), I = 1,2), J = 1,5) /
     *'Error detected by Subroutine 1 (SUBR01)',
     *'R should exceed zero.',
     *'Error detected by Subroutine 1 (SUBR01)',
     *'(zc92/zc50) should be in the range 0 < (zc92/zc50) < 10',
     *'Error detected by Subroutine 2 (SUBR02)',
     *'Mk should be in the range 0 < Mk < 1.0',
     *'Error detected by Subroutine 2 (SUBR02)',
     *'Rk should exceed zero',
     *'Error detected by Subroutine 3 (SUBR03)',
     *'|1 - 2 * (cel/c~)0| should be less than 1.0 '/
C
      DATA ((TXT(I,J), I = 1,2), J = 6,10) /
     *'Error detected by Subroutine 4 (SUBR04)',
     *'|1 - 2 * (cel/c~)m| should be less than 1.0',
     *'Error detected by Subroutine 5 (SUBR05)',
     *'R should exceed zero and [log10(R) - 5] should exceed zero',
     *'Error detected by Subroutine 5 (SUBR05)',
     *'[(a1)0V / (a1)0T]old could not be calculated',
     *'Error detected by Subroutine 7 (SUBR07)',
     *'[(zu125/c) sec(Lambda)] could not be calculated',
     *'Error detected by Subroutine 7 (SUBR07)',
     *'[tan(tau u) * sec(Lambda2)] could not be calculated'/
C
      DATA ((TXT(I,J), I = 1,2), J = 11,15) /
     *'Error detected by Subroutine 11 (SUBR11)',
     *'[(ct/c) / (c~/c)] could not be calculated',
     *'Error detected by Subroutine 11 (SUBR11)',
     *'|2 * (ct/c) / (c~/c) -1| should be less than 1.0',
     *'spare...................................',
     *'........................................',
     *'Error detected by Subroutine 14 (SUBR14)',
     *'(alpha 0)1 could not be calculated',
     *'Error detected by Subroutine 14 (SUBR14)',
     *'cos[(alpha 0)1] should exceed zero.' /
C
      DATA ((TXT(I,J), I = 1,2), J = 16,20) /
     *'Error detected by Subroutine 14 (SUBR14)',
     *'(alpha 0)2 could not be calculated',
     *'Error detected by Subroutine 14 (SUBR14)',
     *'|cos[(alpha 0)2)]| should exceed zero.',
     *'Error detected by Subroutine 14 (SUBR14)',
     *'(alpha 0)3 could not be calculated.',
     *'Error detected by Subroutine 14 (SUBR14)',
     *'|cos[(alpha 0)3)]| should exceed zero.',
     *'Error detected by Subroutine 14 (SUBR14)',
     *'(alpha 0) could not be calculated.' /
C
      DATA ((TXT(I,J), I = 1,2), J = 21,25) /
     *'Error detected by Subroutine 14 (SUBR14)',
     *'alpha*1 could not be calculated',
     *'Error detected by Subroutine 14 (SUBR14)',
     *'cos[alpha*1 - alpha0] should exceed zero.',
     *'Error detected by Subroutine 14 (SUBR14)',
     *'alpha*2 could not be calculated.',
     *'Error detected by Subroutine 14 (SUBR14)',
     *'cos[alpha*2 - alpha0] should exceed zero.',
     *'Error detected by Subroutine 14 (SUBR14)',
     *'alpha*3 could not be calculated.' /
C
      DATA ((TXT(I,J), I = 1,2), J = 26,32) /
     *'Error detected by Subroutine 14 (SUBR14)',
     *'cos[alpha*3 - alpha0] should exceed zero.',
     *'Error detected by Subroutine 14 (SUBR14)',
     *'alpha* could not be calculated.',
     *'Error detected by Subroutine 14 (SUBR14)',
     *'cos[alpha* - alpha0] should exceed zero.',
     *'Error detected by Subroutine 14 (SUBR14)',
     *'cos[alpha - alpha0] should exceed zero.',
     *'Error detected by Subroutine 14 (SUBR14)',
     *'Arrays CL and AD need to be larger. (program error)',
     *'Error detected by Subroutine 14 (SUBR14)',
     *'[0.3 * p / a*] could not be calculated.',
     *'Error detected by Subroutine 14 (SUBR14)',
     *'The second formula for CL could not be calculated.' /
C
      END

